<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation type="obsolete">RDLogin - Estação:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation type="obsolete">rdlogin : </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Não foi possível conectar</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Usuário atual: Desconhecido</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Usuário:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Escolher 
Usuário</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Usuário
Padrão</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation type="obsolete">Usuário Atual:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Senha Inválida!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
